@@ -7,7 +7,7 @@ from pyage_forams.solutions.environment import environment_factory, Environment3
 from pyage_forams.solutions.foram import create_forams, create_agent
 from pyage_forams.solutions.genom import GenomFactory
 from pyage_forams.solutions.insolation_meter import StaticInsolation, DynamicInsolation
-from pyage_forams.solutions.statistics import SimpleStatistics, PsiStatistics
+from pyage_forams.solutions.statistics import SimpleStatistics, PsiStatistics, CsvStatistics, MultipleStatistics
 
 
 factory = GenomFactory(chambers_limit=5)
@@ -34,4 +34,4 @@ environment = environment_factory(regeneration_factor=0.1, clazz=Environment3d)
 stop_condition = lambda: StepLimitStopCondition(90)
 
 address_provider = address.SequenceAddressProvider
-stats = PsiStatistics
\ No newline at end of file
+stats = lambda: MultipleStatistics([CsvStatistics(), PsiStatistics()])
\ No newline at end of file
