@@ -89,12 +89,16 @@ class CsvStatistics(Statistics):
         super(CsvStatistics, self).__init__()
         self.interval = interval
         self.filename = "forams-%s.log" % datetime.now().strftime("%Y%m%d_%H%M%S") if filename is None else filename
+        self.died_so_far = 0
+        self.born_so_far = 0
 
     def update(self, step_count, agents):
         if step_count % self.interval == 0:
             with open(self.filename, 'ab') as f:
                 entry = self._get_entry(agents, step_count)
                 print((",".join(map(str, entry))), file=f)
+        self.died_so_far = Foram._die.called
+        self.born_so_far = Foram._create_child.called
 
     def summarize(self, agents):
         pass
@@ -102,9 +106,9 @@ class CsvStatistics(Statistics):
     def _get_entry(self, agents, step_count):
         forams_count = len(agents[0].forams)
         entry = [step_count, forams_count,
-                 sum(f.chambers for f in agents[0].forams.values()) / float(forams_count) if forams_count > 0 else 0,
-                 sum(c.algae for row in self.environment.grid for c in row),
-                 Foram._reproduce.called]
+                 sum(f.chambers for f in agents[0].forams.values()),
+                 Foram._die.called - self.died_so_far,
+                 Foram._create_child.called - self.born_so_far]
         return entry
 
 
@@ -113,9 +117,9 @@ class PsiStatistics(Statistics):
     def __init__(self, interval=1, filename=None):
         super(PsiStatistics, self).__init__()
         self.interval = interval
-        self._column_names = ['"x"', '"y"', '"z"', '"Foram"', '"Algae"', '"Insolation"']
-        self._column_symbols = ['"F"', '"A"', '"I"']
-        self._column_types = ['float', 'float', 'float']
+        self._column_names = ['"x"', '"y"', '"z"', '"Foram"', '"Energy"', '"Algae"', '"Insolation"']
+        self._column_symbols = ['"F"', '"E"', '"A"', '"I"']
+        self._column_types = ['float', 'float', 'float', 'float']
         self.filename = "forams-%s" % datetime.now().strftime("%Y%m%d_%H%M%S") if filename is None else filename
         self.counter = 0
 
@@ -150,6 +154,7 @@ class PsiStatistics(Statistics):
     def _get_entry(self, x, y, z, step):
         cell = self.environment.grid[x][y][z]
         return map(float, [x, y, z] + [0 if cell.is_empty() else cell.foram.chambers,
+                                       0 if cell.is_empty() else cell.foram.energy,
                                        cell.algae,
                                        self.insolation_meter.get_insolation(cell, step)])
 
@@ -167,15 +172,27 @@ class PsiStatistics(Statistics):
 
 
 class SimpleStatistics(Statistics):
-    @Inject("environment", "insolation_meter", "size")
+    @Inject("environment", "insolation_meter")
     def __init__(self):
         super(SimpleStatistics, self).__init__()
 
     def update(self, step_count, agents):
-        f = [(x, y, z) for x in range(self.size) for y in range(self.size) for z in range(self.size) if
-             not self.environment.grid[x][y][z].is_empty()]
-        logger.info("%d " % (len(f)))
+        if step_count % 150 == 0:
+            logger.info(self.environment.grid)
 
     def summarize(self, agents):
         logger.debug("done")
 
+
+class MultipleStatistics(Statistics):
+    def __init__(self, stats):
+        super(MultipleStatistics, self).__init__()
+        self.stats = stats
+
+    def update(self, step_count, agents):
+        for s in self.stats:
+            s.update(step_count, agents)
+
+    def summarize(self, agents):
+        for s in self.stats:
+            s.summarize(agents)
